%% RXRYRZ2R
% Compute the rotation matrix from a vector with Euler angles (rx,ry,rz)
%
%% Description
%
% Author -
%           Ernesto Homar Teniente Aviles
% 			CONACYT Fellow
%			Institut de Robotica i Informatica Industrial, CSIC-UPC
%           Last change - May, 2010
%
% This code has been developed as part of the EU URUS Project
% FP6-IST-045062
%
% Usage
%   R = rxryrz2R([rx ry rz])
%   R = rxryrz2R([rx; ry; rz])
%   R = rxryrz2R(rx, ry, rz)
%
% Variables:
%   Input:
%
%       [rx ry rz] or [rx; ry; rz] or 
%       rx - a real, rotation angle about axis x (roll, phi)
%       ry - a real, rotation angle about axis y (pitch, theta)
%       rz - a real, rotation angle about axis z (yaw, psi)
%
%       They can be introduced a single vector, or as single parameteres as
%       shown in Usage.
%
%   Outputs:
%       R - a 3 x 3 matrix, rotation matrix
%
%   Notes:
%       The rotation matrix has the form R = RzRyRx
%

%% Code
function R=rxryrz2R(varargin)


switch nargin
  case 1
    tmp =varargin{1};
    rx = tmp(1);
    ry = tmp(2);
    rz = tmp(3);
  case 3
    rx = varargin{1};
    ry = varargin{2};
    rz = varargin{3};
  otherwise
    error('Wrong input parameters')
end

 
 srx = sin(rx); crx = cos(rx);
 sry = sin(ry); cry = cos(ry);
 srz = sin(rz); crz = cos(rz);


R=[cry*crz, srx*sry*crz-crx*srz, crx*sry*crz+srx*srz;
   cry*srz, srx*sry*srz+crx*crz, crx*sry*srz-srx*crz;
   -sry,   srx*cry,          crx*cry         ];



   
   
