% RTPOSE3D -
% Given an homogeneus tranformation matrix, transform a poses set.
%
%% Description
% Author - 	
%           Ernesto Homar Teniente Aviles
% 			CONACYT Fellow
%			Institut de Robotica i Informatica Industrial, CSIC-UPC
%           Last change: 09/2008
%
% This code has been developed as part of the EU URUS Project
% FP6-IST-045062
%
% Usage:
%       posesH = RTpose(H,poses)
%
% Variables:
%   Input:
%       H       - a 3 x 3 matrix, transformation matrix
%       x       - a 1 xn vector, x values
%       y       - a 1 xn vector, y values
%       theta   - a 1 xn vector, theta values
%       poses   - a 3 x n matrix, poses set (x,y,theta), 
%                   According with Lavalle book, Planning Algorithms:
%					*  - roll, rotation angle about the x axis
%					* p - pitch, rotation angle about the y axis
%					* y - yaw, rotation angle about the z axis
%
%   Outputs:
%       posesH  - a 3 x n matrix, transformed poses set 
%                                (x y z roll pitch yaw)

%% Code
function posesH = RtHpose3D(H,x,y,theta)

n = size(x,2);
posesH = zeros(3,n);
for i = 1:n
    % trasformation matrix from the pose i
    Hi = [cos(theta(i)) -sin(theta(i))  x(i);
          sin(theta(i)) cos(theta(i))   y(i);
            0           0         1];
    HHi = H*Hi;
    posesH(:,i) = H2xytheta(HHi);
end

