%% JOINODOFILES -
%  Given a list of odmetry files, this fucntion joins them into a single
%  coordinate frame. Odometry can be returned in to kind od structures as
%  described
%   1.- str_odo.ts =1xn vector, 
%       str_odo.x = 1xn vector, 
%       str_odo.y = 1xn vector, 
%       str_odo.theta = 1xn vector, 
%       str_odo.velt = 1xn vector, 
%       str_odo.velr = 1xn vector.
%
%   2.- str_odo.ts =1xn vector,
%       str_odo.pose = 3xn matrix, [x y theta],
%       str_odo.vel  = 2xn matrix, [velt velr].
%
%
%
%
%

%% CODE

function str_odo = joinOdoFiles(files,varargin)

ret_type =  1;
nvarargin = size(varargin,2);
if ~isempty(varargin)
     if mod(nvarargin,2) 
        error('Wrong arguments!!!');
    end
end

for i=1:2:nvarargin
     switch char(varargin(i)) 
         case 'DataType'
            ret_type = varargin{i+1};
         otherwise
             error('Invalid input parameters')
     end
end

num_files = size(files,2);
fprintf('Opening %d odometry files: ',num_files)
allocCell = cell(1,num_files);
str_odo_tmp = struct(           ...
    'x', allocCell,         ...
    'y', allocCell,         ...
    'theta', allocCell,     ...
    'velt', allocCell,      ...
    'velr', allocCell,      ...
    'ts', allocCell);
n =0;
m = zeros(num_files,1);

for i=1:num_files
  str_odo_tmp(i) = parseOdometrytxt(files(i).File);
  m(i) =size(str_odo_tmp(i).ts,2);
  n = n+m(i);
  fprintf('.')
end
fprintf('DONE\n')

alloc = zeros(1,n);%%cell(1,n);
last.x=0;
last.y=0;
last.theta=0;
last.m=1;
interval.last = 1;
last.H =eye(3);

str_odo_ = struct(              ...
            'x', alloc,         ...
            'y', alloc,         ...
            'theta', alloc,     ...
            'velt', alloc,      ...
            'velr', alloc,      ...
            'ts', alloc);
fprintf('Computing global odometry: ')
for i=1:num_files
  interval.current = interval.last+m(i)-1;
  interval.sz = interval.current-interval.last+1;
  tmp.x = str_odo_tmp(i).x(1,:);
  tmp.y = str_odo_tmp(i).y(1,:);
  tmp.theta = str_odo_tmp(i).theta(1,:);
  tmp.pose = RtHpose3D(last.H, tmp.x, tmp.y, tmp.theta);
  str_odo_.x(1,interval.last:interval.current) = tmp.pose(1,:);
  str_odo_.y(1,interval.last:interval.current) = tmp.pose(2,:);
  str_odo_.theta(1,interval.last:interval.current) =tmp.pose(3,:);
  str_odo_.velt(1,interval.last:interval.current) =str_odo_tmp(i).velt(1,:);
  str_odo_.velr(1,interval.last:interval.current) =str_odo_tmp(i).velr(1,:);
  str_odo_.ts(1,interval.last:interval.current) =str_odo_tmp(i).ts(1,:);
  interval.last= interval.current+1;
  last.x = str_odo_.x(interval.current);
  last.y = str_odo_.y(interval.current);
  last.theta = str_odo_.theta(interval.current);
  tmp_pose = [last.x last.y last.theta];
  fprintf('.')
  last.H = xytheta2H(tmp_pose);
  clear tmp
  %fprintf('i = %d, interval_: %d, x: %f4.4, y: %f4.4, theta: %f4.4\n',...
  %    i,interval.current,last.x,last.y,last.theta);
end

switch ret_type
  case 1
    str_odo = str_odo_;
  case 2
    pose_alloc = zeros(n,3);
    vel_alloc =  zeros(n,2);
    str_odo = struct(           ...
        'pose', pose_alloc,     ...
        'vel', vel_alloc,       ...
        'ts', alloc);
    str_odo.ts =str_odo_.ts;
    str_odo.pose = [str_odo_.x;
                    str_odo_.y;
                    str_odo_.theta];
    str_odo.vel = [str_odo_.velt;
                    str_odo_.velt];
  otherwise
    error('Wrong argument for ret_type, valid values are 1 or 2');
end
fprintf('DONE\n')




