%% POSE3D26D -
% Convert a 3D pose to a 6D pose.
%
%% Description-
%
% Author - 	
%     Ernesto Homar Teniente Aviles
%     CONACYT Scholarship
%     Institut de Robotica i Informatica Industrial, CSIC-UPC
%     Last change -11/2010 
%
% This code has been developed as part of 
% 
% Usage(1):
%
%   pose3D26D(x,y,theta[,OPTIONS])
% 
%   Input :
%
%       x     - a 1xn vector,
%       y     - a 1xn vector,
%       theta - a 1xn vector.
%
%   Note: For Usage(1) deafult's 'OutType' is 1.
%
% Usage(2):
%
%   pose3D26D(data1,[,OPTIONS])
%
%   Input:
%
%       data1 - 3xn matrix, [x;
%                            y;
%                           theta].
%
%   Note: For Usage(2) deafult's 'OutType' is 2.
%
% Options :
%
%   'OutType'   - 
%   'Compass'   - TO DETERMINE, use this option when you have compass
%                 data to enrich pose information
% 	'GPS'       - TO DETERMINE, use this option when you have GPS 
%                 data to enrich pose information
% 
%   Output(1):
%
%       pose.x - 1xn vector,
%       pose.y - 1xn vector,
%       pose.z - 1xn vector,
%       pose.rx - 1xn vector,
%       pose.ry - 1xn vector,
%       pose.rz - 1xn vector,
%       pose.type - a char, 3D.
%
%   Output(2):
%
%       pose.pose - 6xn vector, [x; y; z; rx; ry; rz],
%       pose.type - a char, 6D.
%

%% Code
function pose = pose3D26D(data1,varargin)

[n m]= size(data1);
nvarargin = size(varargin,2);
if ~isempty(varargin)
    if mod(nvarargin,2) && (n==1)
        error('Wrong input arguments!')
    end
end

fprintf('Pose from 3D to 6D ...')
if n==3
    if ~isa(data1, 'double')
        error('Wrong arguments for data1!');
    end
    out_type =2;
elseif n==1
    x = data1; 
    y = varargin{1};
    theta = varargin{2};
    out_type = 1;
    if ~isa(x, 'double')
        if ~isa(y, 'double')
            if ~isa(theta, 'double')
                error('Wrong arguments! \n Numbers ere expected!');
            end
        end
    end
    clear data1
end


if nvarargin >= 4 
    for i=1:2:nvarargin
        % variable = varargin(i);
        switch char(varargin(i)) 
            case 'Compass'
                %compass = varargin{i+1};
            case 'GPS'
                %GPS  = varargin{i+1};
            case 'OutType'
                out_type= varargin{i+1};
        end
    end
end


clear varargin
alloc = zeros(1,m);

% TODO: Add compass and gps data to compute 6D poses

switch out_type
    case 1
        pose.x = x; 
        pose.y = y; 
        pose.z = alloc;
        pose.rx = alloc;
        pose.ry = alloc;
        pose.rz = theta;
    case 2
        pose.pose = [data1(1,:);  
                     data1(2,:) 
                     alloc; 
                     alloc;
                     alloc;
                     data1(3,:)];
                   
end
  pose.type = '6D';
  fprintf('DONE\n')