% Outputs:
%  compass - struct, fileds
%                    + .ts - time stamps
%                    + .data - case 'all', 12xn matrix
%                                Heading     - degrees
%                                Pitch       - degrees
%                                Roll        - degrees
%                                PCalibrated	-
%                                RCalibrated -
%                                IZCalibrated-	
%                                Temperature	- degrees
%                                Distortion	-
%                                CalStatus   -
%                                XAligned    -
%                                YAligned    -
%                                ZAligned    -
%                              case 'orientation' , 3xn matric
%                                Heading,Pitch and Roll degreees
%
%
% NOTES:
%   Units and data order are given according with compass TCM3 by PNI Corp.
%   see ref. man. for mor information 
%     url: http://www.pnicorp.com/products/tcm-legacy
%     url:
%     http://www.tri-m.com/products/precisionnav/files/manual/tcm3_man.pdf

%% CODE
function  compass = parseCompass(files,varargin)

info = process_options(varargin,'Information','orientation' );

nfiles = size(files,1);
fprintf('Parsing %d compass files : ',nfiles )

allocCell = cell(1,1);
compass = struct('data',allocCell,'ts',allocCell);
s =filesep;
for i = 1:nfiles
  fid = importdata(files(i,:) ,'\t',3);
  tmp.ts = fid.data(:,1);
  switch info
    case 'all'
      tmp.data = fid.data(:,2:13);
%       tmp.data(:,2) = -fid.data(:,3);
    case 'orientation'
      tmp.data(:,1) = fid.data(:,2);
      tmp.data(:,2) = fid.data(:,3);
      tmp.data(:,3) = fid.data(:,4);
    otherwise
      error('Wrong information format demanded!')

  end
  compass.ts = [compass.ts tmp.ts'];
  compass.data = [ compass.data tmp.data'];
  fprintf('.')
  clear fid tmp
%   firstline = filelines(i)-1;
end
fprintf(' DONE\n')

end

function nlines = countFileLines(file)

fid = fopen(file);

nlines =0;
  while ~feof(fid)
     fgetl(fid); 
     nlines = nlines+1;
  end
  fclose(fid);
end


function n_reads = compassGetReadsNum(file)

n_lines = countFileLines(file);
n_reads = n_lines-3;
end