% Outputs:
%  compass - struct, fileds
%                    + .ts - time stamps
%                    + .data - case 'all', 12xn matrix
%                                 Status    -
%                                 GPS Time  -
%                                 Latitude  -
%                                 Longitude	-
%                                 Quality   -
%                                 Satellites-	
%                                 HDilution	-
%                                 Altitude	-
%                                 HGeoidal	-
%                                 AgeDGPS   -
%                                 RefDGPS   -
%                               case 'Basic' , 3xn matric
%                                Latitude, longitud and Altitud
%
%
% NOTES:
%   Units and data order are given according with compass TCM3 by PNI Corp.
%   see ref. man. for mor information 
%     url: http://www.pnicorp.com/products/tcm-legacy
%     url:
%     http://www.tri-m.com/products/precisionnav/files/manual/tcm3_man.pdf

%% CODE
function  gps = parseGPS(dataDir,files,varargin)

info = process_options(varargin,'Information','basic' );

nfiles = size(files,2);
fprintf('Parsing %d compass files : ',nfiles )

switch info
  case 'all'
    gps = struct('ts',[],'Status',[],'GPS_Time',[],'Latitude',[],...
             'Longitude',[],'Quality',[],'Satellites',[],...
             'HDilution',[],'Altitude',[],'HGeoidal',[],'AgeDGPS',[],...
             'RefDGPS',[]);
  case 'basic'
   gps = struct('ts',[],'Latitude',[],'Longitude',[],	'Altitude',[]);
end

s =filesep;
for i = 1:nfiles
%   fprintf('Openig file %s: ', [ dataDir files(i).SRC s files(i).File])
  fid = importdata([ dataDir files(i).SRC s files(i).File]);
  
%   fid
  if isfield(fid,'textdata')
    switch info
      case 'all'
        tmp.ts(:,:) = fid.textdata{4:end,1};
        tmp.Status(:,:) = fid.textdata{4:end,2};
        tmp.GPS_Time(:,:)= fid.textdata(4:end,3);
        tmp.Latitude(:,:)= fid.data(:,1);
        tmp.Longitude(:,:)= fid.data(:,2);
        tmp.Quality(:,:)= fid.data(:,3);
        tmp.Satellites(:,:)= fid.data(:,4);
        tmp.HDilution(:,:)= fid.data(:,5);
        tmp.Altitude(:,:)= fid.data(:,6);
        tmp.HGeoidal(:,:)= fid.data(:,7);
        tmp.AgeDGPS(:,:)= fid.data(:,8);
        tmp.RefDGPS(:,:)= fid.data(:,9);
  %       tmp.data(:,2) = -fid.data(:,3);
        gps.Status = [gps.Status tmp.Status'];
        gps.GPS_Time = [gps.GPS_Time tmp.GPS_Time'];
        gps.Quality = [gps.Quality tmp.Quality'];
        gps.Satellites = [gps.Satellites tmp.Satellites'];
        gps.HDilution = [gps.HDilution tmp.HDilution'];
        gps.HGeoidal = [gps.HGeoidal tmp.HGeoidal'];
        gps.AgeDGPS = [gps.AgeDGPS tmp.AgeDGPS'];
        gps.RefDGPS = [gps.RefDGPS tmp.RefDGPS'];
      case 'basic'
        tmp.ts(:,:) = fid.textdata{3:end,1};
        tmp.Latitude= fid.data(:,1);
        tmp.Longitude= fid.data(:,2);
        tmp.Altitude= fid.data(:,6);
      otherwise
        error('Wrong information format demanded!')

    end
    gps.ts = [gps.ts tmp.ts'];
    gps.Latitude =[gps.Latitude tmp.Latitude'];
    gps.Longitude= [gps.Longitude tmp.Longitude'];
    gps.Altitude = [gps.Altitude tmp.Altitude'];
    
    
    clear fid tmp
  %   firstline = filelines(i)-1;
  end
  fprintf('.')
%   fprintf(' DONE\n')
end
fprintf(' DONE\n')

end

function nlines = countFileLines(file)

fid = fopen(file);

nlines =0;
  while ~feof(fid)
     fgetl(fid); 
     nlines = nlines+1;
  end
  fclose(fid);
end


function n_reads = compassGetReadsNum(file)

n_lines = countFileLines(file);
n_reads = n_lines-3;
end