%% PARSEHOKUYO3DONESCAN -
%
%
%
%% Description-
%
% Author - 	
%           Ernesto Homar Teniente Aviles
% 			CONACYT Scholarship
%			Institut de Robotica i Informatica Industrial, CSIC-UPC
% Last change -
%           MAR, 2010 
%
% This code has been developed as part of 
% 
% Usage:
%    scan = parseHokuyo3DOneScan(file{,OPTIONS])
%
% Input:
%
%
%   Options:
%     'OutType' - 1, struct('points', 'intesity','ts','device'),DEFAULT
%                 2, struct('points', 'x','y','z','ts','device')
%     'OnlyTimeStamps' - a bool, 0 DEFAULT.
%     'OnlyPoints'     - a bool, 0 DEFAULT.
%     'NoIntesity'     - a bool, 0 DEFAULT means intesity will be imported
% 
% Output:
%   scan - struct according with 'OutType'
%     NOTE: 'ts' - struct('ini.sec','ini.nsec','end.sec','end.nsec')
%                 ini  - initial scan time
%                 end  - ending  scan time
%                 sec  - seconds
%                 nsec - nanoseconds

%% CODE-
function scan = parseHokuyo3DOneScan2(file,varargin)

chkvarargin(varargin,2);

[out_type ,   ...
 only_ts ,    ...
 only_points, ...
 no_intesity, ...
 intesityinfiles]= process_options(varargin,  ...
                      'OutType', 1,       ...
                      'OnlyTimeStamps',0, ...
                      'OnlyPoints',0,     ...
                      'NoIntesity',0,     ...
                      'IntesityInFiles',0);
       
fid =fopen(file);
fileString = fread(fid,'*char');
fclose(fid);

[read, pos] = textscan(fileString,'%s %s %d %d',2);
if ~only_points
  scan.ts.ini.sec = read{1,3}(1,1);
  scan.ts.ini.nsec = read{1,4}(1,1);
  scan.ts.ini.sec = read{1,3}(2,1);
  scan.ts.ini.nsec = read{1,4}(1,1);
end

if ~only_ts
  if intesityinfiles
    read = textscan(fileString(pos+1:end),'%f %f %f %d' );
    if ~only_points
      scan.intesity = read{1,4}(:)';
    end
  else
    read = textscan(fileString(pos+1:end),'%f %f %f ' );
  end
   
  switch out_type
    case 1
      scan.points = [read{1,1}(:) read{1,2}(:) read{1,3}(:)]'/1000;
    case 2
      scan.x = (read{1,1}(:)/1000)';
      scan.y = (read{1,2}(:)/1000)';
      scan.z = (read{1,3}(:)/1000)';
    otherwise
          error('Invalid argument for out_type!')
  end
  scan.device = 'laser3d';
end 

