function testDataSet(varargin)

% testDataSet.m is an example that shows how to read data files from the
% Barcelona Robot Lab Data Set (BRL)
%
% These parsing tools read all files on the dataset specified with the
% parameter root_dir. If no parameter is given, the evaluation data set is
% loaded, a small subset of the dataset.
%
% IRI Mobile Robotics Group,2011

scrsz = get(0,'ScreenSize');

fprintf( 'Running TEST.\n\n')

s =filesep;

%% Parse a sensors xmls
if nargin < 1
  % Default directory
  root_dir = ['..' s '..' s 'eval_data_set'];  
else
  % your data set directory
  root_dir = varargin{1};
end

initParseTools('.');
fprintf( 'Testing XML parser:.\n\n')
x= getFilesInfo(root_dir, 'Day',0,   ...  
                     'Laser3D',0,      ...
                     'Odometry',0,     ...
                     'Compass',0,      ...
                     'RobotCommands',1,...
                     'StereoCamera', 0, ...
                     'CameraNetwork',0);

n_ =3; % this the index of the data that will be shown in this example

%% Load and display 3d data 
if isfield(x,'laser_3d')
  fprintf( 'Loading a point cloud\n')
  example.scan3D.file = [ root_dir  x.laser_3d(n_).SRC s x.laser_3d(n_).File];
  example.scan3D.data = parseHokuyo3DOneScan(example.scan3D.file)
  figure('Position',[1 scrsz(4)/4 scrsz(3)/2 scrsz(4)/2]); subplot(2,3,[1 5]);
  plot3(example.scan3D.data.points(1,:),...
         example.scan3D.data.points(2,:),...
         example.scan3D.data.points(3,:),'.',...
         'MarkerSize',4);
  title_l1 = ['Range laser points cloud'];
  title_l2 = ['Time stamp: ' x.laser_3d(n_).Time_stamp];
  title({title_l1;title_l2})
  axis equal
  view(-65,65); zoom(4);
  cameratoolbar
  fprintf( 'DONE.\n')
end

%% Load stereo images
if isfield(x,'stereo_cam')
  fprintf( 'Loading images\n')
  for i=1:2
  subplot(2,3,i*3);
  ifile.sc(i,:) = [root_dir  x.stereo_cam(1).SRC s x.stereo_cam(n_+1).File(1,1).Name];
  rgb = imread(ifile.sc(i,:));
  axis equal
  title_l1 = [x.stereo_cam(n_).File(1,i).Side  ' image'];
  title_l2 = ['Time stamp:'  x.stereo_cam(n_).File(1,i).Time_stamp];
  imshow(rgb); title({title_l1;title_l2})
  axis image 
  end
  fprintf( 'DONE.\n')
end

%% Load camera network images
if isfield(x,'cam_net')
  fprintf( 'Loading camera network images\n')
  figure('Position',[scrsz(3)/2 scrsz(4)/4 scrsz(3)/2 scrsz(4)/2]);
  j = 1; k=1;
  for i=1:17
  subplot(3,6,i);
  ifile.cn(i).file = [root_dir  x.cam_net(n_).SRC s x.cam_net(n_).File(1,i).Name];
  rgb = imread(ifile.cn(i).file);
  axis equal
  title_l1 = ['Camera ' x.cam_net(n_).File(1,i).Number];
  title_l2 = ['Time stamp:'  x.cam_net(n_).File(1,i).Time_stamp];
  imshow(rgb); title({title_l1;title_l2})
  k = k+1;
  axis image
  end
  fprintf( 'DONE.\n') 
end

%% Load odometry files
if isfield(x,'odometry')
  fprintf( 'Loading robot odometry\n')
  odometry(1:size(x.odometry,2)) = struct('filedata',[]);
  for i = 1:size(x.odometry,2)
    fprintf( '\t\tOdometry file: %d\n',i)
    odometry(i).filedata =  parseOdometrytxt([ root_dir  ...
              x.odometry(1,i).SRC s x.odometry(1,i).File] );
    disp(odometry(i).filedata)
  end
  fprintf( 'DONE.\n')
end

%% Load compass files
if isfield(x,'compass')
  fprintf( 'Loading compass data\n')
  compass =  parseCompass(root_dir, x.compass, ...
                                   'Information', 'all')
  fprintf( 'DONE.\n')
end
%% Load robot commands
if isfield(x,'robot_commands')
  fprintf( 'Loading robot commands data\n')
  rbt_cmd = joinRobotCmdFiles(x.robot_commands);
  fprintf( 'DONE.\n')
end

%% Load GPS files
if isfield(x,'gps')
  fprintf( 'Loading gps data\n')
  gps = parseGPS(root_dir, x.gps, 'Information', 'all')
  fprintf( 'DONE.\n')
end

%%
 fprintf( 'TEST DONE.\n')